==> ui-18.1.1.tgz: package/components/upload/List.js <==
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isNumber, isUndefined } from 'lodash';
import React, { useState } from 'react';
import { useImmer, useMount } from '@react-devui/hooks';
import { LoadingOutlined, PaperClipOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { TTANSITION_DURING_BASE } from '../../utils';
import { DCollapseTransition } from '../_transition';
import { DProgress } from '../progress';
import { usePrefixConfig } from '../root';
export function DList(props) {
    const { dFileList, dDefaultActions, dActions, onRemove } = props;
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const [removeUIDs, setRemoveUIDs] = useImmer([]);
    const [skipFirstTransition, setSkipFirstTransition] = useState(true);
    useMount(() => {
        setSkipFirstTransition(false);
    });
    return (_jsx("ul", Object.assign({ className: `${dPrefix}upload__list` }, { children: dFileList.map((file, index) => {
            const actions = dActions(file, index);
            return (_jsx(DCollapseTransition, Object.assign({ dOriginalSize: {
                    height: 'auto',
                }, dCollapsedStyle: {
                    height: 0,
                }, dIn: !removeUIDs.includes(file.uid), dDuring: TTANSITION_DURING_BASE, dStyles: {
                    entering: {
                        transition: ['height', 'padding', 'margin'].map((attr) => `${attr} ${TTANSITION_DURING_BASE}ms ease-out`).join(', '),
                    },
                    leaving: {
                        transition: ['height', 'padding', 'margin'].map((attr) => `${attr} ${TTANSITION_DURING_BASE}ms ease-in`).join(', '),
                    },
                    leaved: { display: 'none' },
                }, dSkipFirstTransition: skipFirstTransition, afterLeave: () => {
                    setRemoveUIDs((draft) => {
                        draft.splice(draft.findIndex((uid) => uid === file.uid), 1);
                    });
                    onRemove(file);
                } }, { children: (collapseRef, collapseStyle) => (_jsxs("li", Object.assign({ ref: collapseRef, className: getClassName(`${dPrefix}upload__list-item`, `${dPrefix}upload__list-item--${file.status}`, {
                        [`${dPrefix}upload__list-item--first`]: index === 0,
                    }), style: collapseStyle }, { children: [_jsx("div", Object.assign({ className: `${dPrefix}upload__list-icon` }, { children: file.status === 'progress' ? _jsx(LoadingOutlined, { dSpin: true }) : _jsx(PaperClipOutlined, {}) })), _jsx("a", Object.assign({ className: getClassName(`${dPrefix}upload__list-link`, {
                                'is-active': file.status === 'load' && !isUndefined(file.url),
                            }), target: "_blank", href: file.url, rel: "noreferrer", title: file.name, onClick: (e) => {
                                if (!isUndefined(dDefaultActions === null || dDefaultActions === void 0 ? void 0 : dDefaultActions.preview)) {
                                    e.preventDefault();
                                    dDefaultActions.preview(file);
                                }
                            } }, { children: file.name })), _jsx("div", Object.assign({ className: `${dPrefix}upload__list-actions` }, { children: React.Children.map(actions, (action) => React.cloneElement(action, {
                                __file: file,
                                __defaultActions: dDefaultActions,
                                __onRemove: () => {
                                    setRemoveUIDs((draft) => {
                                        draft.push(file.uid);
                                    });
                                },
                            })) })), _jsx("div", Object.assign({ className: `${dPrefix}upload__list-progress-wrapper` }, { children: isNumber(file.percent) && _jsx(DProgress, { dPercent: file.percent, dLineWidth: 2, dLabel: false }) }))] }))) }), file.uid));
        }) })));
}

==> ui-18.3.7.tgz: package/components/upload/List.js <==
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isNumber, isUndefined } from 'lodash';
import React, { useState } from 'react';
import { useImmer, useMount } from '@react-devui/hooks';
import { LoadingOutlined, PaperClipOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { TTANSITION_DURING_BASE } from '../../utils';
import { DCollapseTransition } from '../_transition';
import { DProgress } from '../progress';
import { usePrefixConfig } from '../root';
export function DList(props) {
    const { dFileList, dDefaultActions, dActions, onRemove } = props;
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const [removeUIDs, setRemoveUIDs] = useImmer([]);
    const [skipFirstTransition, setSkipFirstTransition] = useState(true);
    useMount(() => {
        setSkipFirstTransition(false);
    });
    return (_jsx("ul", Object.assign({ className: `${dPrefix}upload__list` }, { children: dFileList.map((file, index) => {
            const actions = dActions(file, index);
            return (_jsx(DCollapseTransition, Object.assign({ dOriginalSize: {
                    height: 'auto',
                }, dCollapsedStyle: {
                    height: 0,
                }, dIn: !removeUIDs.includes(file.uid), dDuring: TTANSITION_DURING_BASE, dStyles: {
                    entering: {
                        transition: ['height', 'padding', 'margin'].map((attr) => `${attr} ${TTANSITION_DURING_BASE}ms ease-out`).join(', '),
                    },
                    leaving: {
                        transition: ['height', 'padding', 'margin'].map((attr) => `${attr} ${TTANSITION_DURING_BASE}ms ease-in`).join(', '),
                    },
                    leaved: { display: 'none' },
                }, dSkipFirstTransition: skipFirstTransition, afterLeave: () => {
                    setRemoveUIDs((draft) => {
                        draft.splice(draft.findIndex((uid) => uid === file.uid), 1);
                    });
                    onRemove(file);
                } }, { children: (collapseRef, collapseStyle) => (_jsxs("li", Object.assign({ ref: collapseRef, className: getClassName(`${dPrefix}upload__list-item`, `${dPrefix}upload__list-item--${file.status}`), style: collapseStyle }, { children: [_jsx("div", Object.assign({ className: `${dPrefix}upload__list-icon` }, { children: file.status === 'progress' ? _jsx(LoadingOutlined, { dSpin: true }) : _jsx(PaperClipOutlined, {}) })), _jsx("a", Object.assign({ className: getClassName(`${dPrefix}upload__list-link`, {
                                'is-active': file.status === 'load' && !isUndefined(file.url),
                            }), target: "_blank", href: file.url, rel: "noreferrer", title: file.name, onClick: (e) => {
                                if (!isUndefined(dDefaultActions === null || dDefaultActions === void 0 ? void 0 : dDefaultActions.preview)) {
                                    e.preventDefault();
                                    dDefaultActions.preview(file);
                                }
                            } }, { children: file.name })), _jsx("div", Object.assign({ className: `${dPrefix}upload__list-actions` }, { children: React.Children.map(actions, (action) => React.cloneElement(action, {
                                __file: file,
                                __defaultActions: dDefaultActions,
                                __onRemove: () => {
                                    setRemoveUIDs((draft) => {
                                        draft.push(file.uid);
                                    });
                                },
                            })) })), _jsx("div", Object.assign({ className: `${dPrefix}upload__list-progress-wrapper` }, { children: isNumber(file.percent) && _jsx(DProgress, { dPercent: file.percent, dLineWidth: 2, dLabel: false }) }))] }))) }), file.uid));
        }) })));
}
